@@ -169,9 +169,7 @@ gs_grab_get_keyboard (GSGrab    *grab,
         if (status == GDK_GRAB_SUCCESS) {
                 grab->priv->keyboard_grab_window = window;
                 grab->priv->keyboard_grab_screen = screen;
-        }
-
-        if (status != GDK_GRAB_SUCCESS) {
+        } else {
                 gs_debug ("Couldn't grab keyboard!  (%s)", grab_string (status));
         }
 
@@ -464,10 +462,20 @@ gs_grab_grab_window (GSGrab    *grab,
 
         if (kstatus != GDK_GRAB_SUCCESS || mstatus != GDK_GRAB_SUCCESS) {
                 /* Do not blank without a keyboard and mouse grabs. */
+
+                /* Release keyboard or mouse which was grabbed. */
+                if (kstatus == GDK_GRAB_SUCCESS) {
+                        gs_grab_release_keyboard (grab);
+                }
+                if (mstatus == GDK_GRAB_SUCCESS) {
+                        gs_grab_release_mouse (grab);
+                }
+
                 return FALSE;
         }
 
-        return TRUE;			/* Grab is good, go ahead and blank.  */
+        /* Grab is good, go ahead and blank.  */
+        return TRUE;
 }
 
 /* this is used to grab the keyboard and mouse to the root */
