@@ -71,6 +71,8 @@ void        gs_manager_set_keyboard_enabled (GSManager  *manager,
                                              gboolean    enabled);
 void        gs_manager_set_keyboard_command (GSManager  *manager,
                                              const char *command);
+void        gs_manager_set_away_message     (GSManager  *manager,
+                                             const char *message);
 void        gs_manager_get_lock_enabled     (GSManager  *manager,
                                              gboolean   *lock_enabled);
 void        gs_manager_set_lock_enabled     (GSManager  *manager,
